==> osmosis_protobuf-0.0.2.tar.gz: osmosis_protobuf-0.0.2/src/osmosis_protobuf/tendermint/p2p/conn_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ...tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19tendermint/p2p/conn.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto"\x0c\n\nPacketPing"\x0c\n\nPacketPong"R\n\tPacketMsg\x12!\n\nchannel_id\x18\x01 \x01(\x05B\r\xe2\xde\x1f\tChannelID\x12\x14\n\x03eof\x18\x02 \x01(\x08B\x07\xe2\xde\x1f\x03EOF\x12\x0c\n\x04data\x18\x03 \x01(\x0c"\xa6\x01\n\x06Packet\x121\n\x0bpacket_ping\x18\x01 \x01(\x0b2\x1a.tendermint.p2p.PacketPingH\x00\x121\n\x0bpacket_pong\x18\x02 \x01(\x0b2\x1a.tendermint.p2p.PacketPongH\x00\x12/\n\npacket_msg\x18\x03 \x01(\x0b2\x19.tendermint.p2p.PacketMsgH\x00B\x05\n\x03sum"R\n\x0eAuthSigMessage\x123\n\x07pub_key\x18\x01 \x01(\x0b2\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x0b\n\x03sig\x18\x02 \x01(\x0cB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')
_PACKETPING = DESCRIPTOR.message_types_by_name['PacketPing']
_PACKETPONG = DESCRIPTOR.message_types_by_name['PacketPong']
_PACKETMSG = DESCRIPTOR.message_types_by_name['PacketMsg']
_PACKET = DESCRIPTOR.message_types_by_name['Packet']
_AUTHSIGMESSAGE = DESCRIPTOR.message_types_by_name['AuthSigMessage']
PacketPing = _reflection.GeneratedProtocolMessageType('PacketPing', (_message.Message,), {'DESCRIPTOR': _PACKETPING, '__module__': 'tendermint.p2p.conn_pb2'})
_sym_db.RegisterMessage(PacketPing)
PacketPong = _reflection.GeneratedProtocolMessageType('PacketPong', (_message.Message,), {'DESCRIPTOR': _PACKETPONG, '__module__': 'tendermint.p2p.conn_pb2'})
_sym_db.RegisterMessage(PacketPong)
PacketMsg = _reflection.GeneratedProtocolMessageType('PacketMsg', (_message.Message,), {'DESCRIPTOR': _PACKETMSG, '__module__': 'tendermint.p2p.conn_pb2'})
_sym_db.RegisterMessage(PacketMsg)
Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), {'DESCRIPTOR': _PACKET, '__module__': 'tendermint.p2p.conn_pb2'})
_sym_db.RegisterMessage(Packet)
AuthSigMessage = _reflection.GeneratedProtocolMessageType('AuthSigMessage', (_message.Message,), {'DESCRIPTOR': _AUTHSIGMESSAGE, '__module__': 'tendermint.p2p.conn_pb2'})
_sym_db.RegisterMessage(AuthSigMessage)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
    _PACKETMSG.fields_by_name['channel_id']._options = None
    _PACKETMSG.fields_by_name['channel_id']._serialized_options = b'\xe2\xde\x1f\tChannelID'
    _PACKETMSG.fields_by_name['eof']._options = None
    _PACKETMSG.fields_by_name['eof']._serialized_options = b'\xe2\xde\x1f\x03EOF'
    _AUTHSIGMESSAGE.fields_by_name['pub_key']._options = None
    _AUTHSIGMESSAGE.fields_by_name['pub_key']._serialized_options = b'\xc8\xde\x1f\x00'
    _PACKETPING._serialized_start = 97
    _PACKETPING._serialized_end = 109
    _PACKETPONG._serialized_start = 111
    _PACKETPONG._serialized_end = 123
    _PACKETMSG._serialized_start = 125
    _PACKETMSG._serialized_end = 207
    _PACKET._serialized_start = 210
    _PACKET._serialized_end = 376
    _AUTHSIGMESSAGE._serialized_start = 378
    _AUTHSIGMESSAGE._serialized_end = 460

==> osmosis_protobuf-0.1.2.tar.gz: osmosis_protobuf-0.1.2/src/osmosis_protobuf/tendermint/p2p/conn_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ...tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19tendermint/p2p/conn.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto"\x0c\n\nPacketPing"\x0c\n\nPacketPong"R\n\tPacketMsg\x12!\n\nchannel_id\x18\x01 \x01(\x05B\r\xe2\xde\x1f\tChannelID\x12\x14\n\x03eof\x18\x02 \x01(\x08B\x07\xe2\xde\x1f\x03EOF\x12\x0c\n\x04data\x18\x03 \x01(\x0c"\xa6\x01\n\x06Packet\x121\n\x0bpacket_ping\x18\x01 \x01(\x0b2\x1a.tendermint.p2p.PacketPingH\x00\x121\n\x0bpacket_pong\x18\x02 \x01(\x0b2\x1a.tendermint.p2p.PacketPongH\x00\x12/\n\npacket_msg\x18\x03 \x01(\x0b2\x19.tendermint.p2p.PacketMsgH\x00B\x05\n\x03sum"R\n\x0eAuthSigMessage\x123\n\x07pub_key\x18\x01 \x01(\x0b2\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x0b\n\x03sig\x18\x02 \x01(\x0cB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.conn_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
    _PACKETMSG.fields_by_name['channel_id']._options = None
    _PACKETMSG.fields_by_name['channel_id']._serialized_options = b'\xe2\xde\x1f\tChannelID'
    _PACKETMSG.fields_by_name['eof']._options = None
    _PACKETMSG.fields_by_name['eof']._serialized_options = b'\xe2\xde\x1f\x03EOF'
    _AUTHSIGMESSAGE.fields_by_name['pub_key']._options = None
    _AUTHSIGMESSAGE.fields_by_name['pub_key']._serialized_options = b'\xc8\xde\x1f\x00'
    _PACKETPING._serialized_start = 97
    _PACKETPING._serialized_end = 109
    _PACKETPONG._serialized_start = 111
    _PACKETPONG._serialized_end = 123
    _PACKETMSG._serialized_start = 125
    _PACKETMSG._serialized_end = 207
    _PACKET._serialized_start = 210
    _PACKET._serialized_end = 376
    _AUTHSIGMESSAGE._serialized_start = 378
    _AUTHSIGMESSAGE._serialized_end = 460
